@@ -933,7 +933,10 @@ class Data(np.ndarray):
                 repeat=True,
                 title=None,
                 notitle=False,
+                offsets=None,
                 use_si=False,
+                vmin=None,
+                vmax=None,
                 **kwargs):
         """gifアニメーションを作成する
 
@@ -955,9 +958,21 @@ class Data(np.ndarray):
             タイトル(Noneの場合データ名(phisp等)), by default None
         notitle : bool, optional
             タイトルを付けない場合True, by default False
+        offsets : (float or str, float or str, float or str)
+            プロットのx,y,z軸のオフセット('left': 最初を0, 'center': 中心を0, 'right': 最後尾を0, float: 値だけずらす), by default None
         use_si : bool
             SI単位系を用いる場合True(そうでない場合EMSES単位系を用いる), by default False
         """
+        def _offseted(line, offset):
+            if offset == 'left':
+                line -= line[0]
+            elif offset == 'center':
+                line -= line[len(line) // 2]
+            elif offset == 'right':
+                line -= line[-1]
+            else:
+                line += offset
+
         def _update(i, vmin, vmax):
             plt.clf()
 
@@ -970,33 +985,44 @@ class Data(np.ndarray):
             if notitle:
                 _title = title if len(title) > 0 else None
             else:
+                ax = self.slice_axes[axis]
+                slc = self.slices[ax]
+                maxlen = self.shape[axis]
+
+                line = list(utils.range_with_slice(slc, maxlen=maxlen))
+
+                if offsets is not None:
+                    line = _offseted(line, offsets[0])
+
+                index = line[i]
+
                 if use_si:  # SI単位系を用いる場合
                     title_format = title + '({} {})'
-                    ax = self.slice_axes[axis]
                     axisunit = self.axisunits[ax]
                     _title = title_format.format(
-                        axisunit.reverse(i), axisunit.unit)
+                        axisunit.reverse(index), axisunit.unit)
 
                 else:  # EMSES単位系を用いる場合
                     title_format = title + '({})'
-                    slc = self.slices[self.axisunits[axis]]
-                    maxlen = self.shape[axis]
-                    ax = list(utils.range_with_slice(slc, maxlen=maxlen))
-                    index = ax[i]
                     _title = title_format.format(index)
 
+            if offsets is not None:
+                offsets2d = (offsets[1], offsets[2])
+            else:
+                offsets2d = None
+
             val.plot(vmin=vmin, vmax=vmax, title=_title,
-                     use_si=use_si, **kwargs)
+                     use_si=use_si, offsets=offsets2d, **kwargs)
 
         if title is None:
             title = self.name
 
         if use_si:
-            vmin = self.valunit.reverse(self.min())
-            vmax = self.valunit.reverse(self.max())
+            vmin = vmin or self.valunit.reverse(self.min())
+            vmax = vmax or self.valunit.reverse(self.max())
         else:
-            vmin = self.min()
-            vmax = self.max()
+            vmin = vmin or self.min()
+            vmax = vmax or self.max()
 
         if fig is None:
             fig = plt.figure()
@@ -1100,7 +1126,7 @@ class Data2d(Data):
 
         return super().__new__(cls, input_array, **kwargs)
 
-    def plot(self, axes='auto', show=False, use_si=False, **kwargs):
+    def plot(self, axes='auto', show=False, use_si=False, offsets=None, **kwargs):
         """2次元データをプロットする.
 
         Parameters
@@ -1111,6 +1137,8 @@ class Data2d(Data):
             プロットを表示する場合True(ファイルに保存する場合は非表示), by default False
         use_si : bool
             SI単位系を用いる場合True(そうでない場合EMSES単位系を用いる), by default False
+        offsets : (float or str, float or str, float or str)
+            プロットのx,y,z軸のオフセット('left': 最初を0, 'center': 中心を0, 'right': 最後尾を0, float: 値だけずらす), by default None
         mesh : (numpy.ndarray, numpy.ndarray), optional
             メッシュ, by default None
         savefilename : str, optional
@@ -1185,6 +1213,22 @@ class Data2d(Data):
             _ylabel = axes[1]
             _title = self.name
 
+        def _offseted(line, offset):
+            if offset == 'left':
+                line -= line[0]
+            elif offset == 'center':
+                line -= line[len(line) // 2]
+            elif offset == 'right':
+                line -= line[-1]
+            else:
+                line += offset
+            return line
+
+        if offsets is not None:
+            x = _offseted(x, offsets[0])
+            y = _offseted(y, offsets[1])
+            z = _offseted(z, offsets[2])
+
         kwargs['xlabel'] = kwargs.get('xlabel', None) or _xlabel
         kwargs['ylabel'] = kwargs.get('ylabel', None) or _ylabel
         kwargs['title'] = kwargs.get('title', None) or _title
@@ -1218,7 +1262,7 @@ class Data1d(Data):
 
         return super().__new__(cls, input_array, **kwargs)
 
-    def plot(self, show=False, use_si=False, **kwargs):
+    def plot(self, show=False, use_si=False, offsets=None, **kwargs):
         """1次元データをプロットする.
 
         Parameters
@@ -1227,6 +1271,8 @@ class Data1d(Data):
             プロットを表示する場合True(ファイルに保存する場合は非表示), by default False
         use_si : bool
             SI単位系を用いる場合True(そうでない場合EMSES単位系を用いる), by default False
+        offsets : (float or str, float or str)
+            プロットのx,y軸のオフセット('left': 最初を0, 'center': 中心を0, 'right': 最後尾を0, float: 値だけずらす), by default None
         savefilename : str, optional
             保存するファイル名, by default None
         vmin : float, optional
@@ -1275,6 +1321,21 @@ class Data1d(Data):
             _xlabel = self.use_axes[0]
             _ylabel = self.name
 
+        def _offseted(line, offset):
+            if offset == 'left':
+                line -= line[0]
+            elif offset == 'center':
+                line -= line[len(line) // 2]
+            elif offset == 'right':
+                line -= line[-1]
+            else:
+                line += offset
+            return line
+
+        if offsets is not None:
+            x = _offseted(x, offsets[0])
+            y = _offseted(y, offsets[1])
+
         kwargs['xlabel'] = kwargs.get('xlabel', None) or _xlabel
         kwargs['ylabel'] = kwargs.get('ylabel', None) or _ylabel
 
@@ -1285,3 +1346,138 @@ class Data1d(Data):
             return None
         else:
             return line
+
+
+class VectorData2d(utils.Group):
+    def __init__(self, x_data, y_data):
+        super().__init__([x_data, y_data])
+        self.x_data = x_data
+        self.y_data = y_data
+
+    def __setattr__(self, key, value):
+        if key in ('x_data', 'y_data'):
+            super().__dict__[key] = value
+            return
+        super().__setattr__(key, value)
+
+    def plot(self, axes='auto', show=False, use_si=False, offsets=None, **kwargs):
+        """2次元データをプロットする.
+
+        Parameters
+        ----------
+        axes : str, optional
+            プロットする軸('xy', 'zx', etc), by default 'auto'
+        show : bool
+            プロットを表示する場合True(ファイルに保存する場合は非表示), by default False
+        use_si : bool
+            SI単位系を用いる場合True(そうでない場合EMSES単位系を用いる), by default False
+        offsets : (float or str, float or str, float or str)
+            プロットのx,y,z軸のオフセット('left': 最初を0, 'center': 中心を0, 'right': 最後尾を0, float: 値だけずらす), by default None
+        mesh : (numpy.ndarray, numpy.ndarray), optional
+            メッシュ, by default None
+        savefilename : str, optional
+            保存するファイル名(Noneの場合保存しない), by default None
+        cmap : matplotlib.Colormap or str or None, optional
+            カラーマップ, by default cm.coolwarm
+        vmin : float, optional
+            最小値, by default None
+        vmax : float, optional
+            最大値, by default None
+        figsize : (float, float), optional
+            図のサイズ, by default None
+        xlabel : str, optional
+            x軸のラベル, by default None
+        ylabel : str, optional
+            y軸のラベル, by default None
+        title : str, optional
+            タイトル, by default None
+        interpolation : str, optional
+            用いる補間方法, by default 'bilinear'
+        dpi : int, optional
+            解像度(figsizeが指定された場合は無視される), by default 10
+
+        Returns
+        -------
+        AxesImage or None
+            プロットしたimageデータ(保存またはshowした場合None)
+
+        Raises
+        ------
+        Exception
+            プロットする軸のパラメータが間違っている場合の例外
+        Exception
+            プロットする軸がデータにない場合の例外
+        Exception
+            データの次元が2でない場合の例外
+        """
+        if axes == 'auto':
+            axes = ''.join(sorted(self.objs[0].use_axes))
+
+        if not re.match(r'x[yzt]|y[xzt]|z[xyt]|t[xyz]', axes):
+            raise Exception(
+                'Error: axes "{axes}" cannot be used with Data2d'.format(axes=axes))
+        if axes[0] not in self.objs[0].use_axes or axes[1] not in self.objs[0].use_axes:
+            raise Exception(
+                'Error: axes "{axes}" cannot be used because {axes}-axis does not exist in this data.'.format(axes=axes))
+        if len(self.objs[0].shape) != 2:
+            raise Exception(
+                'Error: axes "{axes}" cannot be used because data is not 2dim shape.'.format(axes=axes))
+
+        # x: 3, y: 2, z:1 t:0
+        axis1 = self.objs[0].slice_axes[self.objs[0].use_axes.index(axes[0])]
+        axis2 = self.objs[0].slice_axes[self.objs[0].use_axes.index(axes[1])]
+
+        x = np.arange(*utils.slice2tuple(self.objs[0].slices[axis1]))
+        y = np.arange(*utils.slice2tuple(self.objs[0].slices[axis2]))
+        z = self.objs[0] if axis1 > axis2 else self.objs[0].T  # 'xz'等の場合は転置
+
+        if use_si:
+            xunit = self.objs[0].axisunits[axis1]
+            yunit = self.objs[0].axisunits[axis2]
+            valunit = self.objs[0].valunit
+
+            x = xunit.reverse(x)
+            y = yunit.reverse(y)
+            z = valunit.reverse(z)
+
+            _xlabel = '{} [{}]'.format(axes[0], xunit.unit)
+            _ylabel = '{} [{}]'.format(axes[1], yunit.unit)
+            _title = '{} [{}]'.format(
+                self.objs[0].name, self.objs[0].valunit.unit)
+        else:
+            _xlabel = axes[0]
+            _ylabel = axes[1]
+            _title = self.objs[0].name
+
+        def _offseted(line, offset):
+            if offset == 'left':
+                line -= line[0]
+            elif offset == 'center':
+                line -= line[len(line) // 2]
+            elif offset == 'right':
+                line -= line[-1]
+            else:
+                line += offset
+
+        if offsets is not None:
+            x = _offseted(x, offsets[0])
+            y = _offseted(y, offsets[1])
+            z = _offseted(z, offsets[2])
+
+        kwargs['xlabel'] = kwargs.get('xlabel', None) or _xlabel
+        kwargs['ylabel'] = kwargs.get('ylabel', None) or _ylabel
+        kwargs['title'] = kwargs.get('title', None) or _title
+
+        mesh = np.meshgrid(x, y)
+        img = emplt.plot_2d_vector(
+            self.x_data, self.y_data, mesh=mesh, **kwargs)
+
+        if show:
+            plt.show()
+            return None
+        else:
+            return img
+
+    def __getitem__(self, key):
+        item = super().__getitem__(key)
+        return VectorData2d(*item.objs)
